/*==============================================================================


       eg_4 - IMAGE manipulation example


==============================================================================*/
#include <string.h>

#include "gui.h"
#include "ebm_object.h"

extern "C"
{
#include "ereader_hostio.h"
}
/*==============================================================================

      CPickList

==============================================================================*/
class CPickList : public CList
{

  private:

    const char **m_entries; // The array of character strings.
    U16 GetRowHeight(S32 row)
    {  return GUI_FontHeight(GetWindow()->GetFont());            }
    void DrawRow(RECT *rect, S32 row)
    {  GetWindow()->DrawText(m_entries[row], rect->x, rect->y);  }

  public:

    CPickList(int id,int dx,int dy,int numRows,const char **entries )
    : CList(id,dx,dy,numRows,0), m_entries(entries)
    {}

};
/*==============================================================================

       constants and list captions for the various image entries

==============================================================================*/
#include "mona.cpp"
//------------------------------------------------------------------------------
// copy flags - captions and corresponding values
static const char *s_listImgCmb[]={ "SRC", "AND", "IOR", "XOR", "SRC_INV",
                                    "AND_INV", "IOR_INV", "XOR_INV" };
static const ImgCmb s_valueImgCmb[]={ IMG_CMB_SRC, IMG_CMB_AND, IMG_CMB_IOR,
                                      IMG_CMB_XOR, IMG_CMB_SRC_INV, IMG_CMB_AND_INV,
                                      IMG_CMB_IOR_INV, IMG_CMB_XOR_INV };
//------------------------------------------------------------------------------
// color plane values captions and matching values
static const char *s_listImage[]=  { "16 color", "4 color", "2 color" };
static const IMAGE*s_valueImage[]= { &mona16_image, &mona4_image, &mona2_image };
//------------------------------------------------------------------------------
// color entries - captions and matching values
static const char *s_listColor[]=  { "Default", "BLACK", "GRAY13", "GRAY27",
                 "GRAY40", "GRAY53", "GRAY67", "GRAY80", "GRAY93", "WHITE" };
static const COLOR s_valueColor[]= { 0, COLOR_BLACK,  COLOR_GRAY13, COLOR_GRAY27,
                                        COLOR_GRAY40, COLOR_GRAY53, COLOR_GRAY67,
                                        COLOR_GRAY80, COLOR_GRAY93, COLOR_WHITE };
/*==============================================================================

       CWindow1 - test window

==============================================================================*/
class CWindow1 : public CWindow
{

  private:

    enum { ID_WINDOW=100, ID_LIST1, ID_LIST2, ID_LIST3, ID_LIST4, ID_CAPTION };

    CTextEdit *m_caption;
    int  m_indexForeground, m_indexBackground, m_indexCopyMode, m_indexImage;

    S32  MsgHandler( MSG_TYPE type, CViewable *from, S32 data );
    void Draw(void);
    void DisplayStatus(void);

  public:

    CWindow1(void);

};
//------------------------------------------------------------------------------
CWindow1::CWindow1(void)
 : CWindow( ID_WINDOW,0,0,200,240,"Example 4 - Images",FALSE,FALSE,TRUE)
{
  AddChild(new CPickList(ID_LIST1,80,40,sizeof(s_listImage)/sizeof(s_listImage[0]),
           s_listImage),  5,   5);
  AddChild(new CPickList(ID_LIST2,80,40,sizeof(s_listImgCmb)/sizeof(s_listImgCmb[0]),
           s_listImgCmb), 5,  50);
  AddChild(new CPickList(ID_LIST3,80,40,sizeof(s_listColor)/sizeof(s_listColor[0]),
           s_listColor),  5,  95);
  AddChild(new CPickList(ID_LIST4,80,40,sizeof(s_listColor)/sizeof(s_listColor[0]),
           s_listColor),  5, 140);
  m_caption=new CTextEdit(ID_CAPTION,186,25,TEXTOPTION_NOEDIT|TEXTOPTION_NOUNDERLINE);
  AddChild(m_caption,5,190);
  // set defaults
  m_indexForeground=0;
  m_indexBackground=0;
  m_indexCopyMode  =0;
  m_indexImage     =0;
  DisplayStatus();
}
//------------------------------------------------------------------------------
void CWindow1::DisplayStatus(void)
{
  char buff[299]="";
  sprintf(buff,"%s, IMG_CMB_%s, Fore=%s, Back=%s",
               s_listImage[m_indexImage],
               s_listImgCmb[m_indexCopyMode],
               s_listColor[m_indexForeground],
               s_listColor[m_indexBackground] );
  m_caption->SetText(buff);
}
//------------------------------------------------------------------------------
void CWindow1::Draw(void)
{
  CWindow::Draw(); // do basic window drawing (border, etc)
  // get the window area to tile with 'teeny mona'
  RECT rect;
  GetUsableRect(&rect); // window interior dimensions (drawable surface)
  const IMAGE *ptr=&mona_teeny_image;
  DrawTiledImage(0,0,rect.width,rect.height,ptr,0,0,0,0,ptr->img_width,ptr->img_height,IMG_CMB_SRC);
  // now draw 'big mona' with appropriate user settings
  ptr=s_valueImage[m_indexImage];
  DrawImage( 90,20,                               // destination top left corner
             ptr,                                 // IMAGE structure pointer
             s_valueColor[m_indexForeground],     // foreground color
             s_valueColor[m_indexBackground],     // background color
             0,0,ptr->img_width,ptr->img_height,  // source image shape
             s_valueImgCmb[m_indexCopyMode]);     // copy mode
  DrawChildren(); // draw over top with children, buttons, etc
}
//------------------------------------------------------------------------------
S32 CWindow1::MsgHandler( MSG_TYPE type, CViewable *from, S32 data )
{
  if ( MSG_ROW_SELECT==type )
  {
    switch (from->GetID() )
    {
      case ID_LIST1: // color planes
        m_indexImage     =data;
        break;
      case ID_LIST2: // copy format
        m_indexCopyMode  =data;
        break;
      case ID_LIST3: // foreground color
        m_indexForeground=data;
        break;
      case ID_LIST4: // background color
        m_indexBackground=data;
        break;
    }
    DisplayStatus();
    GUI_NeedUpdate(); // redraw
    return 1;
  }
  return CWindow::MsgHandler(type, from, data);
}
/*==============================================================================


==============================================================================*/
static CWindow1 *f_mainWindow;
//------------------------------------------------------------------------------
S32 GUI_main( MSG_TYPE type, CViewable *object, S32 data )
{
  switch (type)
  {
    case MSG_APP_START:
      if (OS_is_present && hostIO_am_I_the_current_task())
        HOSTIO_INLINE_BREAKPOINT();
      f_mainWindow = new CWindow1();
      return 1;
    case MSG_APP_STOP: // prog exit & cleanup
      delete f_mainWindow;
      return 1;
    default:
      break;
  }
  return 0;
};
//------------------------------------------------------------------------------



